####################################
### Load libraries and functions ###
####################################
wd <- "~/My/Directory/"
setwd(wd) ### set working directory
source("Functions/RJMCMC_functions.R") ### upload the functions needed

###########
### D=4 ###
###########
#######################
### Data simulation ###
#######################
set.seed(3)
### Simulation settings
n=25 # sample size
D=4 #dimension
alpha <- 1 ### Between groups dependence parameter
alpha.b<-c(0.4, 0.8) # Within groups dependence parameters
alphas <- c(alpha,alpha.b)
groups <- list(c(1:2),c(3:4)) ### Defines the underlying tree (only 2 groups here)
### Data simulation
data <- rnlogistic(n,D,alphas,groups) ### nested logistic data 
### Margin standardization
epmax <- apply(data, 2, rank, na.last = "keep")
nasm <- apply(data, 2, function(x) sum(!is.na(x)))
epmax <- epmax/rep(nasm + 1, each = nrow(data))
epmax <- -1/log(epmax) ### numeric matrix containing the extreme observations in Fréchet scale

#################################
### Tree structure estimation ###
#################################
R=10000 ### number of iterations
init.Groups = c(1,1,1,1) ### integer vector containing initial clustering configuration, same integer indicate that the corresponding variables belong to the same group
init.D_K=c(4) ### integer vector containing the size of each initial group
init.alphas.a = c(0.8) ### numeric, contains the initial value for the between clusters dependence parameter
init.alphas.b = c(0.8) ### numeric vector, contains the initial value for the within clusters dependence parameter
set.seed(10)
### here we set the burnin to 0, but it should be set to R/5 to replicate the simulation study...
out.MCMC<-RJMCMC(data=epmax, D=ncol(epmax), R = R, init.Groups =init.Groups, burnin=0, init.D_K=init.D_K, init.alphas.a = init.alphas.a, init.alphas.b = init.alphas.b) ### Perform RJ-MCMC algorithm using the recursive formula of the nested logistic likelihood

out.MCMC$chain ### parameters chain after burnin
out.MCMC$out.alphas.chain ### parameters chain of most likely tree after burnin
out.MCMC$Groups.chain ### Groups chain after burnin
out.MCMC$Groups ### Groups of most likely tree
out.MCMC$groups_distribution ### Summary for groups chain
out.MCMC$alphas ### parameters estimates
out.MCMC$accept.rate.alphas ### acceptance rate for alpha parameters

groups<-matrix(c(1, 1, 1, 1), ncol=4, nrow=1)
groups<-rbind(groups, matrix(c(1, 1, 1, 2), ncol=4, nrow=1), matrix(c(1,1,2,2), ncol=4, nrow=1), matrix(c(1, 1, 2, 3), ncol=4, nrow=1),  matrix(c(1, 2, 3, 2), ncol=4, nrow=1), matrix(c(1, 2, 2, 3), ncol=4, nrow=1), matrix(c(1, 2, 3, 3), ncol=4, nrow=1), matrix(c(1, 2, 3, 4), ncol=4, nrow=1) )

vector<-c()
for(r in 1:R){
	for(g in 1:nrow(groups)){
		if (all(out.MCMC$Groups.chain[r,]==groups[g,])){
			vector<-c(vector, g)
			}
		}
}
plot(1:length(vector),vector, ylim=c(0, 9), xlim=c(0, length(vector)), type="l", xlab="iterations", ylab="Tree structure")
			
############
### D=10 ###
############
#######################
### Data simulation ###
#######################

### Simulation settings
n=1000 # sample size
D=10 #dimension
alpha <- 0.8 ### Between groups dependence parameter
alpha.b<-c(0.4, 0.8, 0.6) # Within groups dependence parameters
alphas <- c(alpha,alpha.b)
groups <- list(c(1:4),c(5:7),c(8:10)) ### defines the underlying tree
### Data simulation
data <- rnlogistic(n,D,alphas,groups) ### nested logistic data 
### Margin standardization
epmax <- apply(data, 2, rank, na.last = "keep")
nasm <- apply(data, 2, function(x) sum(!is.na(x)))
epmax <- epmax/rep(nasm + 1, each = nrow(data))
epmax <- -1/log(epmax) ### numeric matrix containing the extreme observations in Fréchet scale

#################################
### Tree structure estimation ###
#################################
R=2000 ### number of iterations
init.Groups =c(1,1,1,1,1,1,1,1,1,1) ### integer vector containing initial clustering configuration, same integer indicate that the corresponding variables belong to the same group
init.D_K=c(10) ### integer vector containing the size of each initial group
init.alphas.a = c(0.8) ### numeric, contains the initial value for the between clusters dependence parameter
init.alphas.b = c(0.8) ### numeric vector, contains the initial value for the within clusters dependence parameter
set.seed(10)
### here we set the burnin to 0, but it should be set to R/5 to replicate the simulation study...
out.MCMC<-RJMCMC(data=epmax, D=ncol(epmax), R = R, init.Groups =init.Groups, burnin=0, init.D_K=init.D_K, init.alphas.a = init.alphas.a, init.alphas.b = init.alphas.b) ### Perform RJ-MCMC algorithm using the recursive formula of the nested logistic likelihood

out.MCMC$chain ### parameters chain after burnin
out.MCMC$out.alphas.chain ### parameters chain of most likely tree after burnin
out.MCMC$Groups.chain ### Groups chain after burnin
out.MCMC$Groups ### Groups of most likely tree
out.MCMC$groups_distribution ### Summary for groups chain
out.MCMC$accept.alphas.rate ### acceptance rate for alpha parameters
